Learn R Programming

rGhanaCensus (version 0.1.0)

Ghana_2021_school_attendance_geometry: Ghana School Attendance Indicator data plus geometry

Description

The Ghana_2021_school_attendance_geometry dataset contains school attendance indicators for respondents in the 16 regions of Ghana surveyed in the 2021 Ghana Population and Housing Census plus Ghana regional administrative boundaries.

  • Details Age range of survey respondents in this data set 3 years and above.

Usage

Ghana_2021_school_attendance_geometry

Arguments

Format

A data frame with 64 rows and 10 variables:

  • Region

    • A factor with 16 levels with the names of the regions in Ghana

  • Gender

    • A factor with 2 levels

  • Locality

    • A factor with 2 levels describing with the respondents surveyed lived in an urban or rural area

  • Currently_Attending_School

    • numeric column with the raw count values of survey respondents aged 3 years and above currently attending school

  • Percent_Currently_Attending_School

    • A numeric column with the derived percentage of

    • ((Currently_Attending_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Never_Attended_School

    • -A numeric column with the raw count values of survey respondents aged 3 years and above who have never attended school

  • Percent_Never_Attended_School

    • A numeric column with the derived percentage of

    • ((Never_Attended_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Dropped_out_of_School

    • A numeric column with the raw count values of survey respondents aged 3 years and above who were in school but dropped out

  • Percent_Dropped_out_of_School

    • A numeric column with the derived percentage of

    • ((Dropped_out_of_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Sum_of_Respondents_(3_years_and_above)

    • A numeric column with the raw sum values in each row.

    • That is sum of (Currently_Attending_School, Never_Attended_School, Dropped_out_of_School) in each row

Examples

Run this code
# NOT RUN {
#Example

#Create a interactive map with the package tmap that displays the
#regional distribution of percentage of students 3 years or older who have dropped out of school.

#Load required packages
library(sf)
library(tmap)
library(dplyr)
library(magrittr)

#Load geometry data
data("Ghana_2021_school_attendance_geometry", package = "rGhanaCensus")


#Convert to sf data frame and assign a name
#In this example, "Ghana_edu_sf" will be the name of the sf data frame created.

Ghana_edu_sf<- sf::st_as_sf(Ghana_2021_school_attendance_geometry)


#Use tmap to create interactive map
tmap_mode("plot")

Ghana_edu_sf %>%
               dplyr::filter(Locality=="Urban") %>%
               tm_shape()+
               tm_polygons(id="Region", col="Percent_Dropped_out_of_School")+
               tm_text(text="Percent_Dropped_out_of_School")+
               tm_facets(by="Gender")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab