Learn R Programming

rGhanaCensus (version 0.1.0)

Ghana_2021_school_attendance: Ghana School Attendance Indicator data

Description

The Ghana_2021_school_attendance dataset contains school attendance indicators for respondents in the 16 regions of Ghana surveyed in the 2021 Ghana Population and Housing Census.

  • Details -Age range of survey respondents in this data set 3 years and above.

Usage

Ghana_2021_school_attendance

Arguments

Format

A data frame with 64 rows and 10 variables:

  • Region

    • A factor with 16 levels with the names of the regions in Ghana

  • Gender

    • A factor with 2 levels

  • Locality

    • A factor with 2 levels describing with the respondents surveyed lived in an urban or rural area

  • Currently_Attending_School

    • numeric column with the raw count values of survey respondents aged 3 years and above currently attending school

  • Percent_Currently_Attending_School

    • A numeric column with the derived percentage of

    • ((Currently_Attending_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Never_Attended_School

    • -A numeric column with the raw count values of survey respondents aged 3 years and above who have never attended school

  • Percent_Never_Attended_School

    • A numeric column with the derived percentage of

    • ((Never_Attended_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Dropped_out_of_School

    • A numeric column with the raw count values of survey respondents aged 3 years and above who were in school but dropped out

  • Percent_Dropped_out_of_School

    • A numeric column with the derived percentage of

    • ((Dropped_out_of_School)/Sum_of_Respondents_(3_years_and_above))*100 to two decimal places

  • Sum_of_Respondents_(3_years_and_above)

    • A numeric column with the raw sum values in each row.

    • That is sum of (Currently_Attending_School, Never_Attended_School, Dropped_out_of_School) in each row